@@ -223,6 +223,7 @@ class Config
         bool bCheckStatus;
         bool bShowWishlist;
         bool bNotifications;
+        bool bIncludeHiddenProducts;
 
         bool bVerbose;
         bool bUnicode; // use Unicode in console output
@@ -230,6 +231,9 @@ class Config
         bool bReport;
         bool bRespectUmask;
         bool bPlatformDetection;
+#ifdef USE_QT_GUI_LOGIN
+        bool bEnableLoginGUI;
+#endif
 
         // Cache
         bool bUseCache;
