@@ -59,9 +59,8 @@ std::string Util::makeRelativeFilepath(const std::string& path, const std::strin
 std::string Util::getFileHash(const std::string& filename, unsigned hash_id)
 {
     unsigned char digest[rhash_get_digest_size(hash_id)];
-    char result[rhash_get_hash_length(hash_id)];
+    char result[rhash_get_hash_length(hash_id) + 1];
 
-    rhash_library_init();
     int i = rhash_file(hash_id, filename.c_str(), digest);
     if (i < 0)
         std::cerr << "LibRHash error: " << strerror(errno) << std::endl;
@@ -74,9 +73,8 @@ std::string Util::getFileHash(const std::string& filename, unsigned hash_id)
 std::string Util::getChunkHash(unsigned char *chunk, uintmax_t chunk_size, unsigned hash_id)
 {
     unsigned char digest[rhash_get_digest_size(hash_id)];
-    char result[rhash_get_hash_length(hash_id)];
+    char result[rhash_get_hash_length(hash_id) + 1];
 
-    rhash_library_init();
     int i = rhash_msg(hash_id, chunk, chunk_size, digest);
     if (i < 0)
         std::cerr << "LibRHash error: " << strerror(errno) << std::endl;
@@ -141,14 +139,14 @@ int Util::createXML(std::string filepath, uintmax_t chunk_size, std::string xml_
     std::cout << "Getting MD5 for chunks" << std::endl;
 
     rhash rhash_context;
-    rhash_library_init();
     rhash_context = rhash_init(RHASH_MD5);
     if(!rhash_context)
     {
         std::cerr << "error: couldn't initialize rhash context" << std::endl;
+        fclose(infile);
         return res;
     }
-    char rhash_result[rhash_get_hash_length(RHASH_MD5)];
+    char rhash_result[rhash_get_hash_length(RHASH_MD5) + 1];
 
     for (i = 0; i < chunks; i++) {
         uintmax_t range_begin = i*chunk_size;
@@ -160,6 +158,7 @@ int Util::createXML(std::string filepath, uintmax_t chunk_size, std::string xml_
         if (chunk == NULL)
         {
             std::cerr << "Memory error" << std::endl;
+            fclose(infile);
             return res;
         }
         size = fread(chunk, 1, chunk_size, infile);
@@ -167,6 +166,7 @@ int Util::createXML(std::string filepath, uintmax_t chunk_size, std::string xml_
         {
             std::cerr << "Read error" << std::endl;
             free(chunk);
+            fclose(infile);
             return res;
         }
 
@@ -629,3 +629,42 @@ std::string Util::getStrippedString(std::string str)
     );
     return str;
 }
+
+std::string Util::makeEtaString(const unsigned long long& iBytesRemaining, const double& dlRate)
+{
+    boost::posix_time::time_duration duration(boost::posix_time::seconds((long)(iBytesRemaining / dlRate)));
+
+    return Util::makeEtaString(duration);
+}
+
+std::string Util::makeEtaString(const boost::posix_time::time_duration& duration)
+{
+    std::string etastr;
+    std::stringstream eta_ss;
+
+    if (duration.hours() > 23)
+    {
+       eta_ss << duration.hours() / 24 << "d " <<
+                 std::setfill('0') << std::setw(2) << duration.hours() % 24 << "h " <<
+                 std::setfill('0') << std::setw(2) << duration.minutes() << "m " <<
+                 std::setfill('0') << std::setw(2) << duration.seconds() << "s";
+    }
+    else if (duration.hours() > 0)
+    {
+       eta_ss << duration.hours() << "h " <<
+                 std::setfill('0') << std::setw(2) << duration.minutes() << "m " <<
+                 std::setfill('0') << std::setw(2) << duration.seconds() << "s";
+    }
+    else if (duration.minutes() > 0)
+    {
+       eta_ss << duration.minutes() << "m " <<
+                 std::setfill('0') << std::setw(2) << duration.seconds() << "s";
+    }
+    else
+    {
+       eta_ss << duration.seconds() << "s";
+    }
+    etastr = eta_ss.str();
+
+    return etastr;
+}
